@@ -11,7 +11,7 @@
 #include <Quotient/events/roomevent.h>
 #include <Quotient/events/roommessageevent.h>
 
-#include "enums/delegatetype.h"
+#include "enums/messagecomponenttype.h"
 
 class LinkPreviewer;
 class NeoChatRoom;
@@ -31,30 +31,12 @@ class ReactionModel;
  *       information. This is to minimize warnings from QML especially during startup
  *       and room changes.
  */
-class EventHandler : public QObject
+class EventHandler
 {
-    Q_OBJECT
+    Q_GADGET
 
 public:
-    /**
-     * @brief Return the current room the EventHandler is using.
-     */
-    const NeoChatRoom *getRoom() const;
-
-    /**
-     * @brief Set the current room the EventHandler to using.
-     */
-    void setRoom(const NeoChatRoom *room);
-
-    /**
-     * @brief Return the current event the EventHandler is using.
-     */
-    const Quotient::Event *getEvent() const;
-
-    /**
-     * @brief Set the current event the EventHandler to using.
-     */
-    void setEvent(const Quotient::RoomEvent *event);
+    EventHandler(const NeoChatRoom *room, const Quotient::RoomEvent *event);
 
     /**
      * @brief Return the Matrix ID of the event.
@@ -62,13 +44,9 @@ public:
     QString getId() const;
 
     /**
-     * @brief Return the DelegateType of the event.
-     *
-     * @note While similar this is not the matrix event or message type. This is
-     *       to tell a QML ListView what delegate to show for each event. So while
-     *       similar to the spec it is not the same.
+     * @brief The MessageComponentType to use to visualise the main event content.
      */
-    DelegateType::Type getDelegateType() const;
+    MessageComponentType::Type messageComponentType() const;
 
     /**
      * @brief Get the author of the event in context of the room.
@@ -159,6 +137,14 @@ public:
      */
     bool isHidden();
 
+    /**
+     * @brief The input format of the body in the message.
+     *
+     * I.e. if the message has only a body the format will be Qt::PlainText, if it
+     * has a formatted body it will be Qt::RichText.
+     */
+    static Qt::TextFormat messageBodyInputFormat(const Quotient::RoomMessageEvent &event);
+
     /**
      * @brief Output a string for the room message content without any formatting.
      *
@@ -243,6 +229,7 @@ public:
      *  - width - The width in pixels of the audio media.
      *  - height - The height in pixels of the audio media.
      *  - tempInfo - mediaInfo (with the same properties as this except no tempInfo) for a temporary image while the file downloads.
+     *  - isSticker - Whether the image is a sticker or not
      */
     QVariantMap getMediaInfo() const;
 
@@ -257,13 +244,9 @@ public:
     QString getReplyId() const;
 
     /**
-     * @brief Return the DelegateType of the event replied to.
-     *
-     * @note While similar this is not the matrix event or message type. This is
-     *       to tell a QML ListView what delegate to show for each event. So while
-     *       similar to the spec it is not the same.
+     * @brief The MessageComponentType to use to visualise the reply content.
      */
-    DelegateType::Type getReplyDelegateType() const;
+    MessageComponentType::Type replyMessageComponentType() const;
 
     /**
      * @brief Get the author of the event replied to in context of the room.
@@ -338,6 +321,7 @@ public:
      *  - width - The width in pixels of the audio media.
      *  - height - The height in pixels of the audio media.
      *  - tempInfo - mediaInfo (with the same properties as this except no tempInfo) for a temporary image while the file downloads.
+     *  - isSticker - Whether the image is a sticker or not
      */
     QVariantMap getReplyMediaInfo() const;
 
@@ -419,11 +403,10 @@ private:
 
     KFormat m_format;
 
-    DelegateType::Type getDelegateTypeForEvent(const Quotient::RoomEvent *event) const;
-
     QString getBody(const Quotient::RoomEvent *event, Qt::TextFormat format, bool stripNewlines) const;
     QString getMessageBody(const Quotient::RoomMessageEvent &event, Qt::TextFormat format, bool stripNewlines) const;
 
     QVariantMap getMediaInfoForEvent(const Quotient::RoomEvent *event) const;
-    QVariantMap getMediaInfoFromFileInfo(const Quotient::EventContent::FileInfo *fileInfo, const QString &eventId, bool isThumbnail = false) const;
+    QVariantMap
+    getMediaInfoFromFileInfo(const Quotient::EventContent::FileInfo *fileInfo, const QString &eventId, bool isThumbnail = false, bool isSticker = false) const;
 };
