@@ -31,11 +31,6 @@ class SearchModel : public QAbstractListModel
      */
     Q_PROPERTY(QString searchText READ searchText WRITE setSearchText NOTIFY searchTextChanged)
 
-    /**
-     * @brief The current connection that the model is using to search for messages.
-     */
-    Q_PROPERTY(Quotient::Connection *connection READ connection WRITE setConnection NOTIFY connectionChanged)
-
     /**
      * @brief The current room that the search is being done from.
      */
@@ -56,8 +51,7 @@ public:
      * since the same delegates are used.
      */
     enum Roles {
-        DisplayRole = Qt::DisplayRole,
-        DelegateTypeRole,
+        DelegateTypeRole = Qt::DisplayRole + 1,
         ShowAuthorRole,
         AuthorRole,
         ShowSectionRole,
@@ -68,25 +62,15 @@ public:
         ExcessReadMarkersRole,
         HighlightRole,
         ReadMarkersString,
-        PlainTextRole,
         VerifiedRole,
-        ProgressInfoRole,
         ShowReactionsRole,
-        IsReplyRole,
-        ReplyAuthorRole,
-        ReplyIdRole,
-        ReplyDelegateTypeRole,
-        ReplyDisplayRole,
-        ReplyMediaInfoRole,
         ReactionRole,
         ReadMarkersRole,
         IsPendingRole,
         ShowReadMarkersRole,
-        MimeTypeRole,
-        ShowLinkPreviewRole,
-        LinkPreviewRole,
         IsThreadedRole,
         ThreadRootRole,
+        ContentModelRole,
     };
     Q_ENUM(Roles)
     explicit SearchModel(QObject *parent = nullptr);
@@ -94,9 +78,6 @@ public:
     QString searchText() const;
     void setSearchText(const QString &searchText);
 
-    Quotient::Connection *connection() const;
-    void setConnection(Quotient::Connection *connection);
-
     NeoChatRoom *room() const;
     void setRoom(NeoChatRoom *room);
 
@@ -130,7 +111,6 @@ public:
 
 Q_SIGNALS:
     void searchTextChanged();
-    void connectionChanged();
     void roomChanged();
     void searchingChanged();
 
@@ -141,8 +121,7 @@ private:
     void setSearching(bool searching);
 
     QString m_searchText;
-    Quotient::Connection *m_connection = nullptr;
-    NeoChatRoom *m_room = nullptr;
+    QPointer<NeoChatRoom> m_room;
     Quotient::Omittable<Quotient::SearchJob::ResultRoomEvents> m_result = Quotient::none;
     Quotient::SearchJob *m_job = nullptr;
     bool m_searching = false;
