@@ -51,6 +51,8 @@ public:
         IsDeclaredParentRole,
         CanRemove,
         ParentRoomRole,
+        OrderRole,
+        ChildTimestampRole,
     };
 
     explicit SpaceChildrenModel(QObject *parent = nullptr);
@@ -129,7 +131,7 @@ Q_SIGNALS:
     void loadingChanged();
 
 private:
-    NeoChatRoom *m_space = nullptr;
+    QPointer<NeoChatRoom> m_space;
     SpaceTreeItem *m_rootItem;
 
     bool m_loading = false;
@@ -141,5 +143,10 @@ private:
     SpaceTreeItem *getItem(const QModelIndex &index) const;
 
     void refreshModel();
+
+#if Quotient_VERSION_MINOR >= 9
+    void insertChildren(std::vector<Quotient::GetSpaceHierarchyJob::SpaceHierarchyRoomsChunk> children, const QModelIndex &parent = QModelIndex());
+#else
     void insertChildren(std::vector<Quotient::GetSpaceHierarchyJob::ChildRoomsChunk> children, const QModelIndex &parent = QModelIndex());
+#endif
 };
